/*dvd2xvid

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

# include "Zeitfelder.h"

# ifndef ZEITFELDER_CPP
# define ZEITFELDER_CPP

Zeitfelder::Zeitfelder(QWidget *parent, int vertical, int horizontal,int startdebug,bool korrekturfeld)
{
    // Debuglevel setzen
    debuglevel=startdebug;

    // Speichert das Eltern Widget ab
    eltern=parent;

    // Speichert die Positions Angaben ab
    posver=vertical;
    poshor=horizontal;

    // Erzeugen des Stundenfeldes
    stunden = new QLineEdit(eltern);

    // Nur Ganze Zahlen zwischen 0 und 23 zulassen fuer Stunden
    QIntValidator *stundenvalidator = new QIntValidator(0,23,this);
    stunden->setValidator(stundenvalidator);
    stunden->setMaxLength(2);
    stunden->setFont(QFont("SansSerif",12));

     // Erzeugen des Minutenfeldes
    minuten = new QLineEdit(eltern);
    minuten->setMaxLength(2);
    minuten->setFont(QFont("SansSerif",12));

    // Erzeugen des Sekundenfeldes
    sekunden = new QLineEdit(eltern);
    sekunden->setMaxLength(2);
    sekunden->setFont(QFont("SansSerif",12));

    // Nur Ganze Zahlen zwischen 0 und 59 zulassen fuer minuten und sekunden
    QIntValidator *minutenvalidator = new QIntValidator(0,59,this);
    minuten ->setValidator(minutenvalidator);
    sekunden->setValidator(minutenvalidator);

    // Position der des Feldes festlegen
    stunden ->setGeometry(posver,poshor,30,25);
    minuten ->setGeometry(posver+50,poshor,30,25);
    sekunden->setGeometry(posver+100,poshor,30,25);

    // Erzeugen des korrekturfeldes wenn noetig
    if(korrekturfeld==true)
    {
        // Nur Ganze Zahlen zwischen 0 und 59 zulassen fuer minuten und sekunden
        QIntValidator *korrekturValidator = new QIntValidator(-99,99,this);

        korrektur = new QLineEdit(eltern);
        korrektur->setFont(QFont("SansSerif",12));
        korrektur->setMaxLength(3);
        korrektur->setValidator(korrekturValidator);
        korrektur->setGeometry(posver+200,poshor,30,25);

        korrektur->setText("00");

        QLabel *labelKorrektur = new QLabel("Offset :",eltern);
        labelKorrektur->setGeometry(posver+150,poshor,50,25);
        labelKorrektur->setFont(QFont("SansSerif",10));

        QObject::connect(korrektur,  SIGNAL(textChanged(const QString&)),      this,      SLOT(slotKorrektur(const QString&)));
    }


    // Standartwert zuweisen
    ruecksetzen();

    // Doppel Punkte dazwischen fuegen
    QLabel *doppelpunkte1 = new QLabel(":",eltern);
    doppelpunkte1 ->setGeometry(posver+37,poshor,5,25);
    doppelpunkte1 ->setFont(QFont("Helvetica",12,QFont::Bold));

    // Zeiter Doppelpunkt dazufuegen
    QLabel *doppelpunkte2 = new QLabel(":",eltern);
    doppelpunkte2 ->setGeometry(posver+87,poshor,5,25);
    doppelpunkte2 ->setFont(QFont("Helvetica",12,QFont::Bold));

    /************************************/
    /*              Events              */
    /************************************/

    // Wenn eines der Drei Felder geandert wird soll der komplette string gesendet werden
    QObject::connect(stunden,    SIGNAL(textChanged(const QString&)),      this,      SLOT(zusammenfuegen(const QString&)));
    QObject::connect(minuten,    SIGNAL(textChanged(const QString&)),      this,      SLOT(zusammenfuegen(const QString&)));
    QObject::connect(sekunden,   SIGNAL(textChanged(const QString&)),      this,      SLOT(zusammenfuegen(const QString&)));
}

void Zeitfelder::zusammenfuegen(const QString& uebergabe)
{
    if(debuglevel>=2)
    {
        cout<<" * Slot : zusammenfuegen *"<<endl<<endl;
    }

    // Holt sich den Inhalt aller drei Felder und fuegt ihn zusammen 
    dreifelder=stunden->text()+":"+minuten->text()+":"+sekunden->text();

    if(debuglevel>=3)
    {
        cout<<" Vor Kontrolle dreifelder = "<<dreifelder<<endl<<endl;
    }

    // Kontrolliert die Werte der Zeichenkette
    kontrolle();

    if(debuglevel>=3)
    {
        cout<<" Nach Kontrolle dreifelder = "<<dreifelder<<endl<<endl;
    }

    // Sendet das Signal mit den zusammen gebauten Feldern Stunden:Minuten:sekunten
    emit zeitgeaendert(dreifelder);

}

void Zeitfelder::ruecksetzen(void)
{
    // Standartwert zuweisen
    stunden ->setText("00");
    minuten ->setText("00");
    sekunden->setText("00");
}

void Zeitfelder::korrektur_zuruecksetzen(void)
{
    korrektur->setText("00");
}

void Zeitfelder::kontrolle(void)
{
    // Temporaere Variable fuer die Kontolle, entspricht der Basis des Zahlensystems
    int temp=10;

    if(debuglevel>=2)
    {
        cout<<" * Slot : kontrolle *"<<endl<<endl;
    }
    // Kontrolle der Stunden Zahl
    pruefen=dreifelder.left(2);

    // Kontrollieren ob das erste Feld Leer ist
    leerkontrolle=pruefen.at(0);

    if(":"==leerkontrolle)
    {
        dreifelder.insert(0,"00");
    }
    else
    {
        // Nur Kontrolle ob es moeglich waere die Zahl umzuwandeln, wird aber nicht richtig umgewandelt
        pruefen.toInt(&boolkontrolle,temp);

        // Wenn noetig entferne das entsprechende Zeichen
        if(boolkontrolle==false)
        {
            dreifelder.insert(0,"0");
        }
    }

    if(debuglevel>=3)
    {
        cout<<" Stundenkontrolle  = "<<pruefen<<" + boolkontrolle = "<<boolkontrolle<<endl;
    }

    // Kontrolle der sekunden Zahl
    pruefen=dreifelder.mid(2,2);



    if("::"==pruefen)
    {
        dreifelder.insert(3,"00");
    }
    else
    {
        // Kontrolle der sekunden Zahl
        pruefen=dreifelder.mid(3,2);

        // Kontrollieren ob das letzte Feld Leer ist
        leerkontrolle=pruefen.at(1);

        if(":"==leerkontrolle)
        {
            dreifelder.insert(3,"0");
        }
    }

     if(debuglevel>=3)
    {
        cout<<" Minutenkontrolle  = "<<pruefen<<" + boolkontrolle = "<<boolkontrolle<<endl;
    }

    // Kontrolle der sekunden Zahl
    pruefen=dreifelder.right(2);

    // Kontrollieren ob das letzte Feld Leer ist
    leerkontrolle=pruefen.at(pruefen.length()-1);

    if(":"==leerkontrolle)
    {
        dreifelder.insert(dreifelder.length(),"00");
    }
    else
    {
        // Nur Kontrolle ob es moeglich waere die Zahl umzuwandeln, wird aber nicht wirklich umgewandelt
        pruefen.toInt(&boolkontrolle,temp);

        // Wenn noetig entferne das entsprechende Zeichen
        if(boolkontrolle==false)
        {
            dreifelder.insert((dreifelder.length()-1),"0");
        }
    }
    if(debuglevel>=3)
    {
        cout<<" Sekundenkontrolle = "<<pruefen<<" + boolkontrolle = "<<boolkontrolle<<endl<<endl;
    }

}

void Zeitfelder::setDebug (int newDebug)
{
    // Debuglevel neu setzen
    debuglevel=newDebug;
}

void Zeitfelder::slotKorrektur (const QString& uebergabe)
{
    // Den neuen Wert senden
    emit korrekturgeandert(uebergabe);
}

void Zeitfelder::setDeutsch(void)
{
    QToolTip::setWakeUpDelay(2000);
    QToolTip::setFont(QFont("SansSerif",11));
    QToolTip::add( korrektur,"Verschiebt die Anfangs- und/oder Endzeiten\num den eingestellten Sekunden Wert." );
}

void Zeitfelder::setEnglish(void)
{
    QToolTip::setWakeUpDelay(2000);
    QToolTip::setFont(QFont("SansSerif",11));
            QToolTip::add( korrektur,"Moves Start- and/or Endtime with the specified second value." );
}
# endif
